@@ -1,6 +1,5 @@
 package POE::Component::Server::IRC::Help;
-our $AUTHORITY = 'cpan:BINGOS';
-$POE::Component::Server::IRC::Help::VERSION = '1.62';
+BEGIN { $POE::Component::Server::IRC::Help::VERSION = '1.63'; }
 use strict;
 use warnings;
 
